<?php 
use yii\widgets\ActiveForm;
use yii\helpers\Html;
/**
 * @var yii\web\View $this
 * @var modules\oauth2\models\OauthScopes $model
 */
$this->title = 'Create Scope';
?>

<div class="scopes-form">
    <?php $form = ActiveForm::begin(); ?>
        <?= $form->field($model, 'scope')->textInput() ?>
        <?= $form->field($model, 'is_default')->checkbox() ?>
        <?= Html::SubmitButton('Save', ['class' => 'btn btn-success']) ?>
    <?php ActiveForm::end(); ?>
</div>