<?php

/* @var $this \yii\web\View */
/* @var $content string */

use backend\assets\PreloginAssets;
use yii\helpers\Html;
use common\widgets\Alert;

PreloginAssets::register($this);
?>
<?php $this->beginPage() ?>
<!DOCTYPE html>
<html lang="<?= Yii::$app->language ?>">

    <head>
        <meta charset="<?= Yii::$app->charset ?>">
        <meta name="viewport" content="width=device-width, initial-scale=1">
        <?= Html::csrfMetaTags() ?>
        <title><?= Html::encode($this->title) ?></title>
        <?php $this->head() ?>
    </head>
    <?php $this->beginBody() ?>
    <body class="skin-ngauge">
        <div class="container-fluid">
            <header class="main-header">
                <div class="pagetitle pl-3">
                    <?= Yii::$app->name ?>
				</div>
            </header>
        </div>
        <div class="container-fluid">
            <?= Alert::widget() ?>
            <div class="container">
                <?= $content ?>
            </div>
        </div>
        <?php $this->endBody() ?>
    </body>
</html>
<?php $this->endPage() ?>
