<?php
use yii\helpers\Html;
use yii\widgets\ActiveForm;

/* @var $this yii\web\View */
/* @var $client_id string */
/* @var $response_type string */
/* @var $redirect_uri string */
/* @var $state string */
?>

<h1>Authorize</h1>

<p>Do you authorize the app to access your data?</p>

<?php $form = ActiveForm::begin(); ?>

    <?= Html::hiddenInput('client_id', $client_id) ?>
    <?= Html::hiddenInput('response_type', $response_type) ?>
    <?= Html::hiddenInput('redirect_uri', $redirect_uri) ?>
    <?= Html::hiddenInput('state', $state) ?>

    <?= Html::submitButton('Yes', ['name' => 'authorized', 'value' => 'yes']) ?>
    <?= Html::submitButton('No', ['name' => 'authorized', 'value' => 'no']) ?>

<?php ActiveForm::end(); ?>
